/*
  GNOME Comics Organizer
  Copyright (C) 1999-2000 Maxximum Software
   
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <stdio.h>
#include <glib.h>

typedef enum{CO15_16a, CO16b_CO16c, CO17, CO17a, CO17b, CO17c_CO17d, 
	       CO18, CO18b, CO18c, CO19, NotCO, NotFound, GCO_0_1, GCO_0_3} TFileType;

GList *LoadFile(GList *ComicList, FILE *fp);
void SaveFile(GList *ComicList, FILE *fp);
TFileType FileCheck(FILE *fp);
int ExportToASCIIFile(GList *clist, GString *fname);
int ExportToHTMLFile(GList *clist, GString *fname);
